pub(crate) struct AtomicNotified<S: 'static> {
task: AtomicPtr<Header>,
_scheduler: PhantomData<S>,
}Expand description
An atomic cell which can contain a pointer to a Notified task.
This is similar to the crate::util::AtomicCell type, but specialized to
hold a task pointer — this type “remembers” the task’s scheduler generic
when a task is stored in the cell, so that the pointer can be turned back
into a Notified task with the correct generic type when it is retrieved.
Fields
task: AtomicPtr<Header>_scheduler: PhantomData<S>Implementations